function coal_image, data, index_or_corn, out_corn, out_siz, $
	mag=mag, angle=angle, $
	index_out = index_out, $
	cube=cube, $
	qdebug=qdebug, qstop=qstop
;
;+
;NAME:
;	coal_image
;PURPOSE:
;	To perform the scaling and insertion steps for the co-alignment of 
;	two images.
;SAMPLE CALLING SEQUENCE:
;	data_out = coal_image(data, index_or_corn, out_corn, out_siz)
;	data_out = coal_image(data, index, out_corn, out_siz, index_out=index_out)
;	data_out = coal_image(img, corn2sc, out_corn, out_siz)
;INPUT:
;	data	- The data array or cube
;	index_or_corn - The SXT index structure, or the pixel address of the
;		  lower left corner relative to sun center.  The pixel address
;		  is in units of the input image pixel size.
;	out_corn- 2 element array with the lower corner value (relative to
;		  sun center) for the output array in output pixel units.
;	out_siz	- The size of the output image
;KEYWORD INPUT:
;	mag	- If set, change the pixel size of the input image by
;		  that factor.
;	angle	- If set, rotate the input image by this angle
;
;	qdebug	- If set, print some diagnostic messages
;	qstop	- If set, stop before exiting
;KEYWORD OUTPUT:
;	index_out- The new updated SXT index structure.
;METHOD:
;	Call COAL_ROT if "angle" is passed
;	Change the resolution of the input image if "mag" is set
;	Imbed the input image into the output array
;HISTORY:
;	Written by M.Morrison 10-Aug-93
;	22-Dec-93 (MDM) - Various changes
;	31-Aug-94 (MDM) - Put in check that there is overlap in the image
;-
;
his_index, /enable
;
siz = size(index_or_corn)
typ = siz( siz(0)+1 )
if (typ eq 8) then begin
    qindex = 1
    npix = 2^gt_res(index_or_corn)
    cen = sxt_cen(index_or_corn) / npix
    corn_in = gt_corner(index_or_corn) / npix - cen(0:1, *)    ;corner pixel address relative to sun center 
							;(ie: sun center would be at (0,0))
    if (keyword_set(qdebug)) then print, 'Initial CORN_IN value: ', corn_in
    index_out = index_or_corn
end else begin
    qindex = 0
    corn_in = index_or_corn
end
;
if (n_elements(mag) eq 0) then mag = 1.0
;
qangle = 0
if (keyword_set(angle)) then begin
    qangle = 1
    if (qindex) then begin
	data2 = coal_rot(data, angle, index_in=index_or_corn, index_out=index_out, new_corn=new_corn)
    end else begin
	data2 = coal_rot(data, angle, corn2sc=corn_in, new_corn=new_corn)
    end
    corn_in = new_corn		;update corn_in
end
;
siz = size(data)
if (qangle) then siz = size(data2)
typ = siz( siz(0)+1 )
nx0 = siz(1)
ny0 = siz(2)
;
nxout = out_siz(0)
nyout = out_siz(1 < (n_elements(out_siz)-1) )	;handles case where out_siz is a scalar
n   = n_elements(data(0,0,*))
data_out = make_array(nxout, nyout, n, typ=typ)
;
for i=0,n-1 do begin
    x0 = corn_in(0,i)*mag - out_corn(0)
    y0 = corn_in(1,i)*mag - out_corn(1)
    if (qangle) then data3 = congrid(data2(*,*,i), nx0*mag, ny0*mag) $
		else data3 = congrid(data(*,*,i), nx0*mag, ny0*mag)

    if (keyword_set(qdebug)) then begin
	print, 'x0,y0,mag', x0, y0, mag
	print, 'CORN_IN ', corn_in
	print, 'OUT_CORN', out_corn
	help, data3, data_out
    end
    ;
    if (x0 lt 0) then begin
	data3 = data3(abs(x0):*, *)		;trim off the part outside of the output array
	x0 = 0
    end
    if (y0 lt 0) then begin
	data3 = data3(*, abs(y0):*)
	y0 = 0
    end
    if (nxout-1-x0 lt 0) or (nyout-1-y0 lt 0) then begin	;MDM 31-Aug-94 put it check
	print, 'Requested coalignment has no overlap.  Returning zeros'
	data3 = 0
	x0 = 0
	y0 = 0
    end else begin
	if (n_elements(data3(*,0))+x0 gt nxout) then data3 = data3(0:nxout-1-x0, *)
	if (n_elements(data3(0,*))+y0 gt nyout) then data3 = data3(*, 0:nyout-1-y0)
    end

    if (keyword_set(qdebug)) then help, data3
    data_out(x0, y0, i) = data3

    if (qindex) then begin
	his_index, index_out, i, 'corner_sav', out_corn
    end
end
;
if (keyword_set(cube)) then begin
    data_out = [[[cube]], [[temporary(data_out)]]]
end
;
return, data_out
end
