pro goes_summary, start, ndays, big=big, gcolor=gcolor, qdebug=qdebug, $
	above=above, hc=hc, bpp=bpp, three=three, 			$
        one_minute=one_minute, five_minute=five_minute, auto_range=auto_range
;+
;   Name: goes_summary
;
;   Purpose: summarize weekly goes activity / Yohkoh ephemeris on 1 page
;
;   Input Parameters:
;      start - start time for plot (any Yohkoh format)
;      ndays - number of days to summarize (default=7)
;
;   Optional Keyword Parameters:
;      above - (not implemented) goes class cutoff for individual flare display
;      big   - number of individual flare displays 
;      hc    - generate and print ps file
;      bpp   - bits/pixel for PS (default is 4 for speed)
;      
;   Calling Sequence:
;      goes_summary				 ; last 7 days, 6 largest flares
;      goes_summary, start [,ndays , above='M1'] ; indiv flares above M1
;      goes_summary, start [,ndays , big=5]	 ; biggest 5 flares in period
;
;   Description:
;      A single page of plots is produced containing:
;      One plot covering entire time range, no Yohkoh Ephemeris
;      Multiple plots (number depends on above or big parameters, max=9)
;		largest flares for week, expanded time, Yohkoh ephemeris
;
;   History:  
;	25-Oct-92 (SLF) - Written to Simplify Toban duties
;	17-Mar-93 (MDM) - Patch to handle when there are no flares to
;			  blow up
;	18-Mar-93 (MDM) - Added /QDEBUG option
;	30-Mar-93 (SLF) - Document / unclutter
;	10-May-93 (SLF) - Make most recent week default if no input time
;			  added hc keyword, use 4bits/pix by default
;	10-sep-93 (SLF) - Lowered flare threshold (no C flares!)   
;	 2-nov-93 (SLF) - Protect agains no GEV data
;	 6-Dec-93 (SLF) - call evt_grid to tag expanded flares, 
;			  call savesys and restsys (avoid global side effects)
;       30-aug-95 (SLF) - added ONE_MINUTE, FIVE_MINUTE, and AUTO_RANGE keywords
;-
;
savesys,/aplot
dtemp=!d.name
if n_elements(gcolor) eq 0 then gcolor=100
if not keyword_set(above) then above='B2'

case 1 of 
   keyword_set(above): fsize=1	;use goes classs
   keyword_set(big):   fsize=0	;use number of flares
   else: begin			;default is 6 biggest
      fsize=0
      big=6		
   endcase
endcase
if not keyword_set(big) then big=6

if fsize then above=strupcase(above)
;
;
; set up time parameters for summary plot

if n_elements(ndays) eq 0 then ndays=7.
; slf, 10-may - default to most recent week
if n_elements(start) eq 0 then $
  start=fmt_tim(anytim2ints(gt_day(syst2ex(),/str),off= -long(ndays*24*60*60)))

nhours=ndays*24.
;
startint=anytim2ints(start)
stopint=anytim2ints(start,offset=nhours*60.*60)
; derive summary plot title from times
anytim2weeks,startint,stopint,weeks,years
years=years(0) + 1900				; year boundry problem
weekstr=string(weeks,format='(i2.2)')
weekstr=' ' + arr2str(weekstr,'/')
plural=['','s']
isplural=n_elements(weeks) gt 1
title='Summary for Week' + plural(isplural) + weekstr+ ' ' + $
	strtrim(years,2)
;
pmtemp=!p.multi
; Make summary plot via plot_goes
!p.multi=[0,1,2]
help,nhours

if keyword_set(hc) then begin
   set_plot,'ps'
   device,/landscape
   if not keyword_set(bpp) then bpp=4	;default
   message,/info,'Postscript Mode: Landscape, Bits/Pixel= ' + strtrim(bpp,2)
endif

message,/info,'plot_goes, '  + string(start) + string(fix(nhours)) 
plot_goes, start, fix(nhours), title=title, three=three, $
   one_minute=one_minute, five_minute=five_minute, auto_range=auto_range
;
; now read goes event files for flare parameters
rd_gev,startint,stopint,gevdata,status=status
if status ne 0 then begin
   xyouts,.5,.2,'NO GOES EVENT DATA AVAILABLE',/norm,charsize=2.5,align=.5

   message,/info,'No goes event data for period, returning'
   return
endif

;convert flare start, flare peak 
fstarttimes=anytim2ints(gevdata)				
fpeaktimes = anytim2ints(fstarttimes,offset=gevdata.peak)
;
; find all events greater than 'above' and size order, largest first
class=(string(gevdata.st$class))
flares=where(class gt above,flare_count)
if n_elements(class) gt 1 then begin
   classorder=sort(class)
   revorder=reverse(classorder)
endif
;
if (keyword_set(qdebug)) then stop
if (flare_count eq 0) then begin
   xyouts,.5,.2,'NO FLARES GREATER THAN ' + strupcase(above), $
	/norm,charsize=2.5,align=.5
   message,/info,'No flares larger than threshold (' + above + ')'
   return	;MDM added 17-Mar-93
endif
;
;extract the largest events
big=big < flare_count
bigones=revorder(0:big-1)
tobigones=bigones(sort(bigones))
sclass=class(classorder)
message,/info,"Largest Flare was: " + class(bigones(0))
if flare_count gt 0 then $
   message,/info,strtrim(string(flare_count),2) + ' Flares Above Class ' + $
                above + ' occured during this period'

; 
plot_dur=6.		;hours
plot_start=fmt_tim(anytim2ints(fpeaktimes,offset=-(plot_dur/2.*60.*60)))


evt_grid,fpeaktimes(bigones),thick=2
evt_grid,fpeaktimes(bigones),/arrow,tickpos=.94,ticklen=.01

;classes=['A','B','C','M','X']
;normclass=[.652344, .712891, .773438, .832031, .892578]
;bigclass=strmid(class(bigones),0,1)
;remclass=strmid(class(bigones),1,10)
;coord=convert_coord(!x.crange,!y.crange,/data,/to_normal)
;for i=0,n_elements(tobigones)-1 do begin
;   which=where(bigclass(i) eq classes,wcnt)
;   yranmin=.8
;   if wcnt eq 1 then yranmin=normclass(which(0)) + float(alog10(remclass(i)))/10.
;   evt_grid, fpeaktimes(bigones(i)),/arrow ;yrange=[yranmin+.015,coord(1,1)],/arrow
;endfor

; plot formatting
;
;    1 2 3 4 5 6 7 8 9 0
col=[1,2,3,3,3,3,4,4,4,4]
row=[2,2,4,4,4,4,5,5,5,5]
fst=[1,2,6,6,6,6,8,9,10,10]
big=big < n_elements(col)
!p.multi=[fst(big-1),col(big-1),row(big-1)]
for i=0, n_elements(bigones)-1 do begin
   title='Peak: ' + gt_time(fpeaktimes(tobigones(i)),/str) + $
	' Class: ' + class(tobigones(i)) + $
;	' Loc: ' + gevdata(tobigones(i)).location + $ 
	' NOAA AR:' + strtrim(gevdata(tobigones(i)).noaa,2)
   plot_goes,plot_start(tobigones(i)),fix(plot_dur), $
	/filln,/fills,gcolor=gcolor, title=title, /nodeftitle,charsize=1.3, $
	three=three, one_minute=one_minute, five_minute=five_minute, auto_range=auto_range
endfor
if (keyword_set(qdebug)) then stop

if keyword_set(hc) then pprint
set_plot,dtemp	; restore status
!p.multi=pmtemp
restsys,/aplot
end
