pro mk_gx, prefix, infil0, outfil, week=week, run_time=run_time, $
		append=append, usefid=usefid, indir=indir, outdir=outdir, $
		qdebug=qdebug
;
;+
;NAME:
;	mk_gx
;PURPOSE:
;	Generate the GXT, G6D, G7D (GOES light curve) data files
;SAMPLE CALLING SEQUENCE:
;	mk_gx, 'gxt', infil
;	mk_gx, 'g6d', week=week
;	mk_gx, 'g7d', week=week, /append, /usefid
;INPUT:
;	prefix	- The prefix is required.  It must be GXT, G6D, or G7D
;OPTIONAL INPUT:
;	infil0	- A string array with a list of the input file names.
;		  It should include the directory path.  
;		  The inputfiles can be derived if the "week" option is used.
;	outfil	- The output filename to create.  The output
;		  file can be derived if the "week" option is used
;OPTIONAL KEYWORD INPUT:
;	week	- a string with the year/week if the format
;		  91_49 where 91 is the year, 49 is the week
;	append	- If set, try to just append the files in "infil"
;		  list which are not already in the GX file.
;	usefid	- If set, use the FID time in the orbit pointer
;		  (so that it can be recognized when used with
;		  the /append switch)
;	indir	- The input directory
;	outdir	- The output directory
;RESTRICTION:
;	Cannot use /USEFID or /APPEND option with 'GBL' datatype
;HISTORY:
;	Written 13-Apr-93 by M.Morrison
;	14-Apr-93 (MDM) - Expanded to handle GBL
;-
;
start_time = systime(1)
if (n_elements(infil0) ne 0) then infil = infil0
if (n_elements(outdir) eq 0) then outdir = '$DIR_GEN_'+strupcase(prefix)
;
progVerNo = 1.000*1000
progName = 'MK_GX.PRO'
;
if (n_elements(outfil) ne 0) then outfil_final = outfil
if (keyword_set(week)) then begin
    yearn = fix(strmid(week, 0, 2))
    weekn = fix(strmid(week, 3, 2))
    tim1 = anytim2ints(week2ex(yearn, weekn))
    ;
    week2 = weekn + 1
    year2 = yearn
    if (week2 gt 53) then begin & week2=1 & year2=year2+1 & end
    tim2 = anytim2ints(week2ex(year2, week2))		;start day of the next week

    ndays = tim2.day - tim1.day
    fem_data0 = replicate(tim1, ndays)
    fem_data0.day = indgen(ndays) + tim1.day

    ;---- MDM removed stuff below because FEM files do not exist before Sep-91
    ;tim2 = anytim2ints(tim1, off=8*24.*60.*60)
    ;rd_fem, tim1, tim2, fem_data, /full_weeks
    ;ss = where((fem_data.week eq weekn) and (fem_data.day_rev eq 1))
    ;fem_data0 = fem_data(ss)
    ;
    files = ''
    case strupcase(prefix) of
	'GOL': begin
		indir = finddir('gbo'+week+'a')
		infil = file_list(indir, '*')
	       end
	'GXT': begin
		if (n_elements(indir) eq 0) then indir = '$DIR_GEN_GOES'
		days = strlowcase(gt_day(fem_data0, /str, /leadzero))
		days = str_replace(days, '-', '')
		plotseg=['a','b','c','d']               ; four 6hour plots/day
		for i=0,n_elements(days)-1 do files=[files, days(i) + plotseg + '_xr.plot']
		files = files(1:*)
		infil = file_list(indir, files)
	       end 
	'GBL': begin
		if (n_elements(indir) eq 0) then indir = '/yd3/morrison/batse_raw'
		tim1 = gt_day(fem_data0(0), /str)
		tim2 = gt_day( anytim2ints(fem_data0(n_elements(fem_data0)-1), off=24.*60.*60), /str)
		rd_week_file, tim1, tim2, 'GBE', gbe, status=status
		if keyword_set(qdebug) then print, 'GBL searching from ', tim1, ' to ', tim2, ' found: ', n_elements(gbe)
		if (status eq 0) then begin
		    filnam = 'gbl' + ex2fid(anytim2ex(gbe)) + '_f' + string(gbe.event, format='(i4.4)') + '_sav'
		    infil = file_list(indir, filnam)
		end else begin
		    infil = ''
		end
	       end
	else: begin
		if (n_elements(indir) eq 0) then indir = ['/yd7/goes3sec_raw', '/yd8/goes3sec_raw']
		days = strmid( ex2fid( anytim2ex(fem_data0) ), 0, 6)
		plotseg = '.' + string(indgen(8)*300, format='(i4.4)')
		sc_num = 'go0' + strmid(prefix, 1, 1)
		for i=0,n_elements(days)-1 do files = [files, sc_num + days(i) + plotseg]
		files = files(1:*)
		infil = file_list(indir, files)
	       end 
    endcase

    if (infil(0) eq '') then begin
	print, 'MK_GX: No files found for week', week, ' - returning...'
	return
    end
    ;
    weekid = string(week, fix(progverno/1000), format="(a, 'a.', i2.2)")
    outfil       = concat_dir('$DIR_REFORMAT_SC', strlowcase(prefix)+weekid)
    outfil_final = concat_dir(outdir, strlowcase(prefix)+weekid)
end
;
if (n_elements(outfil) eq 0) then begin
    outfil       = concat_dir('$DIR_REFORMAT_SC', strlowcase(prefix)+'_temporary')
    outfil_final = concat_dir(outdir, strlowcase(prefix)+'_temporary')
end
;
;----- Call subroutines that define the structures
;
obs_struct
att_struct
gbo_struct, gbo_version=gbo_version
ref_struct, ref
;
;
;----- Diagnostic variables
;
qprint = 1
qdebug = 1
;
;---------------------------------------- General Stuff
;
lunout = 2	;output 
lun = 3		;for reading the data file
;
gen_struct, file_header=fhead
;
norbitmax       = 31*15
orbit_header    = {obs_neworb_hd_rec}
orbit_arr       = replicate({obs_newOrbit_Rec}, norbitmax)
;
qfirst_time = 1
first_time      = 0
first_day       = 0
last_time       = 0
last_day        = 0
;
rsiz = 16
;
qnew_outfil = 1
if (keyword_set(append) and file_exist(outfil_final)) then begin
    qnew_outfil = 0

    cmd = 'rm -f ' + outfil               ;remove any copy of the file that might already exist
    spawn, cmd
    cmd = 'cp ' + outfil_final + ' ' + outfil
    spawn, cmd

    openu, lunout, outfil, /block, /get_lun

    rd_pointer, lunout, fpoint
    rd_fheader, lunout, fheader
    rd_neworb_p, outfil, orbit_arr0, orbit_header
    norbit = orbit_header.nOrbitRec
    orbit_arr(0:norbit-1) = orbit_arr0
    bytout = fpoint.totbytes                            ;point at end of file
    bytout0 = fpoint.data_section
    ndatasets = fheader.ndatasets

    qfirst_time = 0
    first_time      = orbit_arr(0).time
    first_day       = orbit_arr(0).day

    break_file, infil, dsk_log, dir_in, filnam, ext
    case strupcase(prefix) of
	'GXT': fids = selsis2fid(filnam)
	else:  fids = strmid(filnam, 4, 6)+ext
    endcase
    fids_already = ex2fid(anytim2ex(orbit_arr0))
    ss = where_arr(fids, fids_already)
    nn = n_elements(ss)
    if (max(ss) ne nn-1) then begin
	qnew_outfil = 1				;something was done out of order
						;want ss to start at 0 and increase by 1
						;0,1,2,3,4 is ok, 0,1,5,6,7 is not ok - want files 2,3,4 in order
	print, 'MK_GX: Cannot simply append since there are files out of order'
	print, 'MK_GX: Making a complete new file.
    end else begin
	if (n_elements(ss) eq n_elements(infil)) then begin
	    print, 'MK_GX: No new files found.  Returning'
	    close, 2
	    return
	end
        infil = infil(nn:*)            ;only do the new files
	print, 'MK_GX: Skipping the first ', nn, ' files'
    end
end
if (qnew_outfil) then begin
    print, 'Opening a new output file: ', outfil
    open_da_file, lunout, '', '', outfil, rsiz, bytout, fpoint, /nolower

    fpoint.opt_section	= bytout
    rdwrt, 'W', lunout, bytout, rsiz, Orbit_header, 1
    rdwrt, 'W', lunout, bytout, rsiz, Orbit_arr, 1
    fpoint.data_section	= bytout
    bytout0 = bytout	;first entry record number

    qfirst_time = 1
    ndatasets = 0L
    norbit          = 0		;moved here 11-Nov-92
end
;
nfil = n_elements(infil)
if (strupcase(prefix) eq 'GOL') then nfil = 1		;do it in one step
for ifil=0,nfil-1 do begin
    if (qdebug) then print, 'MK_GX working on file: ', infil(ifil)

    case strupcase(prefix) of
	'GOL': mk_gol_str, infil, data
	'GXT': rd_goestek, infil(ifil), data
	'GBL': rd_gbl_raw, infil(ifil), data
	else: rd_goes3sec, infil(ifil), outrec=data, /rm_bad
    endcase
    nn = n_elements(data)

    if (get_nbytes(data) gt 10) then begin	;see if actually read something
	    if (keyword_set(usefid)) then begin
		break_file, infil(ifil), dsk_log, dir_in, filnam, ext
		case strupcase(prefix) of
		    'GXT': fid = selsis2fid(filnam)
		    else: fid = strmid(filnam, 4, 6)+ext
		endcase
		daytim = anytim2ints( fid2ex(fid) )
		orbit_arr(norbit).time = daytim.time
		orbit_arr(norbit).day  = daytim.day
	    end else begin
		orbit_arr(norbit).time = data(0).time
		orbit_arr(norbit).day  = data(0).day
	    end
	    orbit_arr(norbit).stEntry = ndatasets + 1	;dataset # for which this orbit starts (start counting at 1)
	    norbit = norbit + 1

	    rdwrt, 'W', lunout, bytout, rsiz, data, 1
	    ndatasets = ndatasets + nn

	    if (qfirst_time) then begin
		    first_day = data(0).day
		    first_time = data(0).time
		    qfirst_time = 0
	    end
	    last_day  = data(nn-1).day
	    last_time = data(nn-1).time
    end
end
;
maxsamps = get_nbytes(data(0))
totbytes = bytout
orbit_header.nOrbitRec = norbit
bytout = fpoint.opt_section
rdwrt, 'W', lunout, bytout, rsiz, orbit_header, 1
rdwrt, 'W', lunout, bytout, rsiz, orbit_arr, 1

;-------------------- Write out pointer and file header
;

fpoint.TotBytes		= totbytes

fhead.first_Time	= first_time
fhead.first_Day		= first_day
fhead.last_Time		= last_time
fhead.last_Day		= last_day

fhead.nDataSets		= nDataSets
fhead.maxSamps		= maxSamps

case strupcase(prefix) of
    'GXT': fpoint.data_version     = gbo_version.gxt
    'GBL': fpoint.data_version     = gbo_version.gbl
    else:  fpoint.data_version     = gbo_version.gxd
endcase

file_id = ' '	;TODO - make it something else?
wrt1p_fh, lunout, fpoint, fhead, rsiz, progName, progVerNo, file_id, strupcase(prefix), 'All', spacecraft='GO '
;
close, lunout
;
if (n_elements(outfil_final) ne 0) then if (outfil_final ne outfil) then begin
    cmd = 'rm -f ' + outfil_final               ;remove any copy of the file that might already exist
    spawn, cmd
    cmd = 'mv ' + outfil + ' ' + outfil_final
    spawn, cmd
    cmd = 'chmod +w ' + outfil_final
    spawn, cmd
    outfil = outfil_final
end
;
end_time = systime(1)
run_time = (end_time-start_time)/60.
print, 'MK_GX took', run_time, ' minutes to run'
;
end
