;+
;       NAME: rd_lonlat
;
;       PURPOSE: Read heliocentric sets of coordinates from an image.
;
;       METHOD: Similar to the READ_OUT option of SXT_GRID, except that
;		it returns the selected values, and it will work on
;		non SXT images. The image is refreshed unless the /norefresh
;		keyword is used.
;		Assumes tilt/roll is zero.
;
;       CALLING SEQUENCE:  lonlat=rd_lonlat(main,data[,index][,target=trgt]
;				 	[,date=date][,xy_cent=cent][,/norefresh])
;
;
;       PARAMETERS:  main	the number of the main window
;		     data	the image you want the coordinates for
;		     index   	the index if its an SXT image
;
;       KEYWORDS:    target  	centroid and radius of image, in pixels
;		     date    	for GBO images you need to pass in the 
;				time of the image. Anything the ANYTIM2EX
;				can handle.
;		     xy_cent 	output the image coordinates
;		     norefresh  when set, do not refresh image
;
;	CALLS: TARGET, NEW_WIN, CONV_P2H
;
;       HISTORY: Drafted by A.McAllister, mar-93.
;		 [Based on code from SXT_GRID, by G. Slater]
;		 Added xy_cent keyword, AMcA. 18-mar-93.
;		 Added norefresh keyword, AMcA. 25-mar-93.
;		 Changed to use pixel corner, AMcA. 23-may-93.
;		 Reversed output order to x,y convention, and
;		  replaced VEC_P2H with CONV_P2H, AMcA. 23-jun-93.
;		 Fixed readout format, AMcA. 29-jun-93.
;		 Changed "tilt" to "roll" in CONV_P2H call, AMcA. 29-nov-93.
;
;-
FUNCTION rd_lonlat,main,data,index,target=trgt,date=date,xy_cent=xy_cent, $
				   norefresh=noref

 case n_params() of

	2:	begin

			if keyword_set(trgt) eq 0 then trgt=target(data,/rough)
			if keyword_set(date) eq 0 then begin
			  print,'RD_LONLAT: Please retry using the DATE keyword.'
			  return,-1
			endif

		end

	3:	begin

			if keyword_set(trgt) eq 0 then trgt=target(data,index,/rough)
			date=anytim2ex(index)
		end
 
	else: 	print,'RD_LONLAT: wrong number of parameters';return=-1
 
 endcase

 pixsz=gt_pix_size(index)

 print,'RD_LONLAT:Use the left button to mark points.'
 print,'RD_LONLAT:Use the middle button to select points for output,'
 print,'RD_LONLAT:Use the right button to exit.'

 sub=new_win(256,32,offset=[-260,20])

 wset,main
 if not keyword_set(noref) then tvscl,data
   
 rtn=0

 while rtn ne 4 do begin

      wset,main
      cursor,x,y,3,/device 
      rtn=!err

      if rtn ne 4 then begin

        lonlat=conv_p2h([x,y],date,off_limb=ol,suncenter=trgt(0:1), $
					       radius=trgt(2),roll=0.)   ;pixel corner

        lat = 'LAT: ' + string(lonlat(1),format='$(f7.3)')
        lon = 'LON: ' + string(lonlat(0),format='$(f8.3)')

        wset,sub
        erase
        if ol(0) ne 1 then begin

          xyouts,10,5,lat,/device,charsize=1.5,charthick=1.5
          xyouts,138,5,lon,/device,charsize=1.5,charthick=1.5

          if (rtn eq 2) then begin

            if n_elements(vec_lonlat) eq 0 then begin

	      vec_lonlat=lonlat
	      xy_cent=[x,y]

     	    endif else begin

	      vec_lonlat=[[vec_lonlat],[lonlat]]
  	      xy_cent=[[xy_cent],[x,y]]

	    endelse
 				       
	    wset,main

	    test=fix(total(tvrd(x-3,y-3,10,10))/100)
            if test gt 120 then clr=0 else clr=255
            xyouts,x-3,y-3,'+',/device,color=clr

	    rtn=0

          endif

	endif else xyouts,10,5,'Location is off the limb.',/device,charsize=1.5,charthick=1.5

      endif

 endwhile

 wdelete,sub
 wset,main

 if n_elements(vec_lonlat) eq 0 then return,-1

 return,vec_lonlat

end

