;+
;       NAME:
;             scale_gbo
;
;       PURPOSE:
;               To resize, and repostion a gbo image to match the last
;               sfd image produced by first_light.
;      
;       METHOD: The sfd image is passed through sxt_cen to find the centroid
;               and the axial diameters, the gbo image is passed through gen_loc
;               for the same purpose and is then resized and reposisitioned to 
;               match the first (TARGET).  The rescaled gbo image is then displayed.
;               This is based on A. McA.'s gbo_scale2 procedure.
;
;	CALLING SEQUENCE:
;
;               outimg=scale_gbo(trgimg,gboimg,indx1)
;               outimg=scale_gbo(gboimg,diam=npix)
;               
;               indx1 is the index entry for the sxtimg.
;
;	PARAMETERS:
;	   gboimg      the input GBO image.
;          trgimg      the target image to which it is to be matched.
;	   outimg      the rescaled output image.
;
;	KEYWORDS:
;
;       OUTPUT TYPE:
; 
;       CALLS: SXT_CEN, GET_RB0P, GEN_LOC 
;
;	HISTORY:
;	   Procedure developed to shrink BBSO Halpha image and 
;	   place it correctly in a 512x512 SXT image 
;	   Written by L. Acton  7-nov-91
;	   Modified for generality  10-apr-92
;          Added automatic sun finder, A. McA. 16-apr-92
;          Corrected for different vertical/horizontal scaling A.McA 18-apr-92
;          Version 2. Rewrote for general sized matrices, using dsk_loc.
;          changed calling sequence to include target image, A.McA 24-apr-92
;          Replaced location routine. Can now handle SXT images, A.McA. 6-may-92
;          Added fractional pixel repositioning, A.McA. 7-may-92
;          Changed congrid call to use bilinear extrapolation, A.McA. 26-may-92
;          Output variable type now same as input type, A.McA. 2-dec-92
;          Modified by DA for specific use with first_light.
;          15-Sep-1994 (SLF) add SIZE_ONLY keyword (resize but dont reposition)
;           9-sep-1994 (SLF) allow diam to be passed in (pixels)
;-
FUNCTION scale_gbo,trgimg,gboimg,indx1,cent=cent,rad=rad, $
	diam=diam, size_only=size_only

size_only = keyword_set(size_only) or keyword_set(diam)

if 1-keyword_set(diam) then begin
;  find location of center of sxt image
   cent = sxt_cen(indx1)
   rr   = get_rb0p(indx1,/radius)                 ; radius of sxt image
   rad  = total(rr(0,*))/n_elements(indx1)
   sumi = 1024/n_elements(trgimg(*,0))            ; allow for resolution
   diam  = 2*rad/2.45/sumi                        ; diameter of image in pixels
   x0=cent(0)/sumi
   y0=cent(1)/sumi
endif else if n_params() eq 1 then gboimg=trgimg

;find location of center of gbo image

gbosz=size(gboimg)                            ;size of input image

gen_loc,gboimg,HORZRAD=hzrd,VERTRAD=vtrd

ha=congrid(gboimg,gbosz(1)*diam/hzrd,gbosz(2)*diam/vtrd,/interp)   ;resize the input

gen_loc,ha,CENTROID=centr

hasz = size(ha)                           ;size of resized image
trgsz=size(trgimg)                        ;size of target image

if keyword_set(size_only) then begin	  ;dont reposition, just resize
   x0=trgsz(1)/2
   y0=trgsz(2)/2
endif

dltx=fix(x0-centr(0))                      ;difference to one pixel
dlty=fix(y0-centr(1))

; slf 15-sep-1994 - use make_array (replace replicate)
newsize=trgsz					; size from target
newsize(newsize(0)+1)=hasz(hasz(0)+1)		; data type is from resized
imgout=make_array(size=newsize,value=ha(0))	; make the output array

;copy resized input to output, while centering to nearest pixel
   imgout((0 > dltx):((trgsz(1)-1) < (dltx+hasz(1)-1)),         $
       (0 > dlty):((trgsz(2)-1) < (dlty+hasz(2)-1))) =       $
     ha((0 > (-1*dltx)):((hasz(1)-1) < (trgsz(1)-1-dltx)),   $
        (0 > (-1*dlty)):((hasz(2)-1) < (trgsz(2)-1-dlty)))

;  shift the last fraction, uses interpolation which may change intensity range
;   use min value for 'uncovered' pixels to avoid shifting intensity range.

   fdltx=(x0-centr(0))-fix(x0-centr(0))        ;fractional pixel difference
   fdlty=(y0-centr(1))-fix(y0-centr(1))
 
   imgout=poly_2d(imgout,[-fdltx,0,1,0],[-fdlty,1,0,0],1,missing=ha(0,0))


return,imgout
end

